summaryrefslogtreecommitdiffstats
path: root/kverbos/kverbos/kverbosdoc.h
diff options
context:
space:
mode:
Diffstat (limited to 'kverbos/kverbos/kverbosdoc.h')
-rw-r--r--kverbos/kverbos/kverbosdoc.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/kverbos/kverbos/kverbosdoc.h b/kverbos/kverbos/kverbosdoc.h
index efe5d98c..d2c9f48c 100644
--- a/kverbos/kverbos/kverbosdoc.h
+++ b/kverbos/kverbos/kverbosdoc.h
@@ -42,9 +42,9 @@ class KVerbosUser;
* The KVerbosDoc class provides a document object that can be used in conjunction with
* the classes KVerbosApp and KVerbosView to create a document-view model for standard KDE
* applications based on KApplication and KMainWindow. Thereby, the document object
- * is created by the KVerbosApp instance and contains the document structure with the
+ * is created by the KVerbosApp instance and tqcontains the document structure with the
* according methods for manipulation of the document data by KVerbosView objects. Also,
- * KVerbosDoc contains the methods for serialization of the document data from and to files.
+ * KVerbosDoc tqcontains the methods for serialization of the document data from and to files.
*
* Die Dokumentenklasse hält eine Liste der verfügbaren Verben vor. Aus dieser Liste wird
* eines ausgewählt, das gelernt werden soll. Die View-Klasse kann dieses Verb abfragen und
@@ -113,10 +113,10 @@ class KVerbosDoc : public QObject
const KURL& URL() const;
/** sets the URL of the document */
void setURL(const KURL& url);
/** es wird ein Verb der Liste hinzugefügt, ist emitStatus = true, wird auch
* die Statuszeile entsprechend angepasst.
*/
- void appendVerb(const verbSpanish v, bool emitStatus = true);
+ void appendVerb(const verbSpanish v, bool emitqStatus = true);
/** prüft, ob die Liste des Dokumentes leer ist */
bool isEmpty() const;
/** Gibt einen Zeiger auf die Verbliste des Dokumentes zurück */
@@ -140,8 +140,8 @@ class KVerbosDoc : public QObject
public slots:
/**
- * calls repaint() on all views connected to the document object and is called by the view by which the document has been changed.
- * As this view normally repaints itself, it is excluded from the paintEvent.
+ * calls tqrepaint() on all views connected to the document object and is called by the view by which the document has been changed.
+ * As this view normally tqrepaints itself, it is excluded from the paintEvent.
*/
void slotUpdateAllViews(KVerbosView *sender);
@@ -113,10 +113,10 @@ class KVerbosDoc : public QObject
/** sets the URL of the document */
void setURL(const KURL& url);
- /** es wird ein Verb der Liste hinzugefügt, ist emitStatus = true, wird auch
- * die Statuszeile entsprechend angepasst.
+ /** es wird ein Verb der Liste hinzugefügt, ist emitqStatus = true, wird auch
+ * die tqStatuszeile entsprechend angepasst.
*/